@@ -1,7 +1,7 @@
-use libc::{c_void, c_char, size_t, c_int};
-use core_foundation_sys::base::{Boolean, OSStatus, CFTypeRef};
-use core_foundation_sys::base::CFAllocatorRef;
 use core_foundation_sys::array::CFArrayRef;
+use core_foundation_sys::base::CFAllocatorRef;
+use core_foundation_sys::base::{Boolean, CFTypeRef, OSStatus};
+use libc::{c_char, c_int, c_void, size_t};
 
 use cipher_suite::SSLCipherSuite;
 use trust::SecTrustRef;
@@ -45,15 +45,15 @@ pub const kSSLConnected: SSLSessionState = 2;
 pub const kSSLClosed: SSLSessionState = 3;
 pub const kSSLAborted: SSLSessionState = 4;
 
-pub type SSLReadFunc = unsafe extern "C" fn(connection: SSLConnectionRef,
-                                            data: *mut c_void,
-                                            dataLength: *mut size_t)
-                                            -> OSStatus;
+pub type SSLReadFunc =
+    unsafe extern "C" fn(connection: SSLConnectionRef, data: *mut c_void, dataLength: *mut size_t)
+        -> OSStatus;
 
-pub type SSLWriteFunc = unsafe extern "C" fn(connection: SSLConnectionRef,
-                                             data: *const c_void,
-                                             dataLength: *mut size_t)
-                                             -> OSStatus;
+pub type SSLWriteFunc = unsafe extern "C" fn(
+    connection: SSLConnectionRef,
+    data: *const c_void,
+    dataLength: *mut size_t,
+) -> OSStatus;
 
 pub type SSLProtocolSide = c_int;
 pub const kSSLServerSide: SSLProtocolSide = 0;
@@ -127,116 +127,139 @@ pub const kSSLClientCertRejected: SSLClientCertificateState = 3;
 
 extern "C" {
     pub fn SSLContextGetTypeID() -> ::core_foundation_sys::base::CFTypeID;
-    pub fn SSLCreateContext(alloc: CFAllocatorRef,
-                            protocolSide: SSLProtocolSide,
-                            connectionType: SSLConnectionType)
-                            -> SSLContextRef;
+    pub fn SSLCreateContext(
+        alloc: CFAllocatorRef,
+        protocolSide: SSLProtocolSide,
+        connectionType: SSLConnectionType,
+    ) -> SSLContextRef;
     #[cfg(target_os = "macos")]
     pub fn SSLNewContext(isServer: Boolean, contextPtr: *mut SSLContextRef) -> OSStatus;
     #[cfg(target_os = "macos")]
     pub fn SSLDisposeContext(context: SSLContextRef) -> OSStatus;
     pub fn SSLSetConnection(context: SSLContextRef, connection: SSLConnectionRef) -> OSStatus;
     pub fn SSLGetConnection(context: SSLContextRef, connection: *mut SSLConnectionRef) -> OSStatus;
-    pub fn SSLSetIOFuncs(context: SSLContextRef,
-                         read: SSLReadFunc,
-                         write: SSLWriteFunc)
-                         -> OSStatus;
+    pub fn SSLSetIOFuncs(
+        context: SSLContextRef,
+        read: SSLReadFunc,
+        write: SSLWriteFunc,
+    ) -> OSStatus;
     pub fn SSLHandshake(context: SSLContextRef) -> OSStatus;
     pub fn SSLClose(context: SSLContextRef) -> OSStatus;
-    pub fn SSLRead(context: SSLContextRef,
-                   data: *mut c_void,
-                   dataLen: size_t,
-                   processed: *mut size_t)
-                   -> OSStatus;
-    pub fn SSLWrite(context: SSLContextRef,
-                    data: *const c_void,
-                    dataLen: size_t,
-                    processed: *mut size_t)
-                    -> OSStatus;
-    pub fn SSLSetPeerDomainName(context: SSLContextRef,
-                                peerName: *const c_char,
-                                peerNameLen: size_t)
-                                -> OSStatus;
-    pub fn SSLGetPeerDomainNameLength(context: SSLContextRef,
-                                      peerNameLen: *mut size_t)
-                                      -> OSStatus;
-    pub fn SSLGetPeerDomainName(context: SSLContextRef,
-                                peerName: *mut c_char,
-                                peerNameLen: *mut size_t)
-                                -> OSStatus;
+    pub fn SSLRead(
+        context: SSLContextRef,
+        data: *mut c_void,
+        dataLen: size_t,
+        processed: *mut size_t,
+    ) -> OSStatus;
+    pub fn SSLWrite(
+        context: SSLContextRef,
+        data: *const c_void,
+        dataLen: size_t,
+        processed: *mut size_t,
+    ) -> OSStatus;
+    pub fn SSLSetPeerDomainName(
+        context: SSLContextRef,
+        peerName: *const c_char,
+        peerNameLen: size_t,
+    ) -> OSStatus;
+    pub fn SSLGetPeerDomainNameLength(context: SSLContextRef, peerNameLen: *mut size_t)
+        -> OSStatus;
+    pub fn SSLGetPeerDomainName(
+        context: SSLContextRef,
+        peerName: *mut c_char,
+        peerNameLen: *mut size_t,
+    ) -> OSStatus;
     pub fn SSLSetCertificate(context: SSLContextRef, certRefs: CFArrayRef) -> OSStatus;
     #[cfg(target_os = "macos")]
-    pub fn SSLSetCertificateAuthorities(context: SSLContextRef,
-                                        certificateOrArray: CFTypeRef,
-                                        replaceExisting: Boolean)
-                                        -> OSStatus;
+    pub fn SSLSetCertificateAuthorities(
+        context: SSLContextRef,
+        certificateOrArray: CFTypeRef,
+        replaceExisting: Boolean,
+    ) -> OSStatus;
     #[cfg(target_os = "macos")]
-    pub fn SSLCopyCertificateAuthorities(context: SSLContextRef,
-                                         certificates: *mut CFArrayRef)
-                                         -> OSStatus;
-    pub fn SSLSetSessionOption(context: SSLContextRef,
-                               option: SSLSessionOption,
-                               value: Boolean)
-                               -> OSStatus;
-    pub fn SSLGetSessionOption(context: SSLContextRef,
-                               option: SSLSessionOption,
-                               value: *mut Boolean)
-                               -> OSStatus;
+    pub fn SSLCopyCertificateAuthorities(
+        context: SSLContextRef,
+        certificates: *mut CFArrayRef,
+    ) -> OSStatus;
+    pub fn SSLSetSessionOption(
+        context: SSLContextRef,
+        option: SSLSessionOption,
+        value: Boolean,
+    ) -> OSStatus;
+    pub fn SSLGetSessionOption(
+        context: SSLContextRef,
+        option: SSLSessionOption,
+        value: *mut Boolean,
+    ) -> OSStatus;
     pub fn SSLCopyPeerTrust(context: SSLContextRef, trust: *mut SecTrustRef) -> OSStatus;
     pub fn SSLGetSessionState(context: SSLContextRef, state: *mut SSLSessionState) -> OSStatus;
-    pub fn SSLGetSupportedCiphers(context: SSLContextRef,
-                                  ciphers: *mut SSLCipherSuite,
-                                  numCiphers: *mut size_t)
-                                  -> OSStatus;
-    pub fn SSLGetNumberSupportedCiphers(context: SSLContextRef,
-                                        numCiphers: *mut size_t)
-                                        -> OSStatus;
-    pub fn SSLGetEnabledCiphers(context: SSLContextRef,
-                                ciphers: *mut SSLCipherSuite,
-                                numCiphers: *mut size_t)
-                                -> OSStatus;
+    pub fn SSLGetSupportedCiphers(
+        context: SSLContextRef,
+        ciphers: *mut SSLCipherSuite,
+        numCiphers: *mut size_t,
+    ) -> OSStatus;
+    pub fn SSLGetNumberSupportedCiphers(
+        context: SSLContextRef,
+        numCiphers: *mut size_t,
+    ) -> OSStatus;
+    pub fn SSLGetEnabledCiphers(
+        context: SSLContextRef,
+        ciphers: *mut SSLCipherSuite,
+        numCiphers: *mut size_t,
+    ) -> OSStatus;
     pub fn SSLGetNumberEnabledCiphers(context: SSLContextRef, numCiphers: *mut size_t) -> OSStatus;
-    pub fn SSLSetEnabledCiphers(context: SSLContextRef,
-                                ciphers: *const SSLCipherSuite,
-                                numCiphers: size_t)
-                                -> OSStatus;
+    pub fn SSLSetEnabledCiphers(
+        context: SSLContextRef,
+        ciphers: *const SSLCipherSuite,
+        numCiphers: size_t,
+    ) -> OSStatus;
     pub fn SSLGetNegotiatedCipher(context: SSLContextRef, cipher: *mut SSLCipherSuite) -> OSStatus;
     pub fn SSLSetClientSideAuthenticate(context: SSLContextRef, auth: SSLAuthenticate) -> OSStatus;
     #[cfg(target_os = "macos")]
-    pub fn SSLSetDiffieHellmanParams(context: SSLContextRef,
-                                     dhParams: *const c_void,
-                                     dhParamsLen: size_t)
-                                     -> OSStatus;
+    pub fn SSLSetDiffieHellmanParams(
+        context: SSLContextRef,
+        dhParams: *const c_void,
+        dhParamsLen: size_t,
+    ) -> OSStatus;
     #[cfg(target_os = "macos")]
-    pub fn SSLGetDiffieHellmanParams(context: SSLContextRef,
-                                     dhParams: *mut *const c_void,
-                                     dhParamsLen: *mut size_t)
-                                     -> OSStatus;
-    pub fn SSLSetPeerID(context: SSLContextRef,
-                        peerID: *const c_void,
-                        peerIDLen: size_t)
-                        -> OSStatus;
-    pub fn SSLGetPeerID(context: SSLContextRef,
-                        peerID: *mut *const c_void,
-                        peerIDLen: *mut size_t)
-                        -> OSStatus;
+    pub fn SSLGetDiffieHellmanParams(
+        context: SSLContextRef,
+        dhParams: *mut *const c_void,
+        dhParamsLen: *mut size_t,
+    ) -> OSStatus;
+    pub fn SSLSetPeerID(
+        context: SSLContextRef,
+        peerID: *const c_void,
+        peerIDLen: size_t,
+    ) -> OSStatus;
+    pub fn SSLGetPeerID(
+        context: SSLContextRef,
+        peerID: *mut *const c_void,
+        peerIDLen: *mut size_t,
+    ) -> OSStatus;
     pub fn SSLGetBufferedReadSize(context: SSLContextRef, bufSize: *mut size_t) -> OSStatus;
-    pub fn SSLGetClientCertificateState(context: SSLContextRef,
-                                        clientState: *mut SSLClientCertificateState)
-                                        -> OSStatus;
-    pub fn SSLGetNegotiatedProtocolVersion(context: SSLContextRef,
-                                           protocol: *mut SSLProtocol)
-                                           -> OSStatus;
-    pub fn SSLGetProtocolVersionMax(context: SSLContextRef,
-                                    maxVersion: *mut SSLProtocol)
-                                    -> OSStatus;
-    pub fn SSLGetProtocolVersionMin(context: SSLContextRef,
-                                    minVersion: *mut SSLProtocol)
-                                    -> OSStatus;
+    pub fn SSLGetClientCertificateState(
+        context: SSLContextRef,
+        clientState: *mut SSLClientCertificateState,
+    ) -> OSStatus;
+    pub fn SSLGetNegotiatedProtocolVersion(
+        context: SSLContextRef,
+        protocol: *mut SSLProtocol,
+    ) -> OSStatus;
+    pub fn SSLGetProtocolVersionMax(
+        context: SSLContextRef,
+        maxVersion: *mut SSLProtocol,
+    ) -> OSStatus;
+    pub fn SSLGetProtocolVersionMin(
+        context: SSLContextRef,
+        minVersion: *mut SSLProtocol,
+    ) -> OSStatus;
     pub fn SSLSetProtocolVersionMax(context: SSLContextRef, maxVersion: SSLProtocol) -> OSStatus;
     pub fn SSLSetProtocolVersionMin(context: SSLContextRef, minVersion: SSLProtocol) -> OSStatus;
     #[cfg(target_os = "macos")]
-    pub fn SSLSetProtocolVersionEnabled(context: SSLContextRef,
-                                        protocol: SSLProtocol,
-                                        enable: Boolean) -> OSStatus;
+    pub fn SSLSetProtocolVersionEnabled(
+        context: SSLContextRef,
+        protocol: SSLProtocol,
+        enable: Boolean,
+    ) -> OSStatus;
 }
